@@ -33,7 +33,7 @@ logger = logging.getLogger(__name__)
 class ReferenceSequenceAnnotationProvider(object):
     """Utilities to cache content required to update referencence sequence annotations."""
 
-    def __init__(self, cfgOb, maxChunkSize=100, fetchLimit=None, numProc=2, expireDays=14, **kwargs):
+    def __init__(self, cfgOb, databaseName, collectionName, polymerType, maxChunkSize=100, fetchLimit=None, numProc=2, expireDays=14, **kwargs):
         self.__cfgOb = cfgOb
         self.__mU = MarshalUtil()
         #
@@ -46,7 +46,10 @@ class ReferenceSequenceAnnotationProvider(object):
         self.__ssP = self.__fetchSiftsSummaryProvider(self.__cfgOb, self.__cfgOb.getDefaultSectionName(), **kwargs)
         self.__goP = self.__fetchGoProvider(self.__cfgOb, self.__cfgOb.getDefaultSectionName(), **kwargs)
         self.__ecP = self.__fetchEcProvider(self.__cfgOb, self.__cfgOb.getDefaultSectionName(), **kwargs)
-        self.__rsaP = ReferenceSequenceCacheProvider(self.__cfgOb, siftsProvider=self.__ssP, maxChunkSize=maxChunkSize, numProc=numProc, fetchLimit=fetchLimit, expireDays=expireDays)
+        #
+        self.__rsaP = ReferenceSequenceCacheProvider(
+            self.__cfgOb, databaseName, collectionName, polymerType, siftsProvider=self.__ssP, maxChunkSize=maxChunkSize, numProc=numProc, fetchLimit=fetchLimit, expireDays=expireDays
+        )
         self.__matchD = self.__rsaP.getMatchInfo()
         self.__refD = self.__rsaP.getRefData()
         self.__missingMatchedIdCodes = self.__rsaP.getMissingMatchedIdCodes()
@@ -157,7 +160,12 @@ class ReferenceSequenceAnnotationProvider(object):
         cacheKwargs = kwargs.get("cacheKwargs", {"fmt": "pickle"})
         useCache = kwargs.get("useCache", True)
         #
-        srcDirPath = os.path.join(cachePath, cfgOb.getPath("SIFTS_SUMMARY_DATA_PATH", sectionName=configName))
+        siftsSummaryDataPath = cfgOb.getPath("SIFTS_SUMMARY_DATA_PATH", sectionName=configName)
+        # logger.info("Using SIFTS_SUMMARY_DATA_PATH, %r", siftsSummaryDataPath)
+        if siftsSummaryDataPath.lower().startswith("http"):
+            srcDirPath = siftsSummaryDataPath
+        else:
+            srcDirPath = os.path.join(cachePath, siftsSummaryDataPath)
         cacheDirPath = os.path.join(cachePath, cfgOb.get("SIFTS_SUMMARY_CACHE_DIR", sectionName=configName))
         logger.debug("ssP %r %r", srcDirPath, cacheDirPath)
         ssP = SiftsSummaryProvider(srcDirPath=srcDirPath, cacheDirPath=cacheDirPath, useCache=useCache, abbreviated=abbreviated, cacheKwargs=cacheKwargs)
